@@ -1,7 +1,8 @@
 import bs4
+import datetime
 
 UA = {
-    'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/67.0.3396.99 Safari/537.36'
+    "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/67.0.3396.99 Safari/537.36"
 }
 
 Mobile_UA = {
@@ -36,7 +37,7 @@ def AssertUserURL(para):
         return False
     return True
 
-def AssertNoteURL(para):
+def AssertArticleURL(para):
     """该函数接收一个参数，并判断其是否是简书的文章 URL。
 
     Args:
@@ -64,4 +65,22 @@ def Process_HTML(html):
         item = item.replace(' target="_blank"',"")
         result_html.append(item)
     result_html = "".join(result_html)
-    return result_html
\ No newline at end of file
+    return result_html
+
+def StrToDatetime(text):
+    """该函数接收一个由简书接口返回的字符串，并构建一个 Datetime 对象
+
+    Args:
+        text (str): 源字符串
+
+    Returns:
+        datetime: UTC+8，精确到秒
+    """
+    year = int(text[0:4])
+    month = int(text[5:7])
+    day = int(text[8:10])
+    hour = int(text[11:13])
+    minute = int(text[14:16])
+    second = int(text[17:19])
+    result = datetime.datetime(year,month,day,hour,minute,second)
+    return result
\ No newline at end of file
