@@ -9,6 +9,9 @@ except ImportError:
     from Errors import *
 
 import json
+import time
+import re
+import datetime
 
 import bs4
 import requests
@@ -129,7 +132,7 @@ def GetUserAssetsCount(user_url):
     raw_data = source.findAll("div",class_ = "meta-block")[5].p.text
     return float(raw_data.replace(".","").replace("w","000")) # 处理资产大于一定值时的缩写
 
-def GetUserBasicImformation(user_url):
+def GetUserBasicInformation(user_url):
     """该函数接收一个链接字符串，访问后提取用户的几项基础信息。
 
     Args:
@@ -142,13 +145,13 @@ def GetUserBasicImformation(user_url):
     source = bs4.BeautifulSoup(html.content,parser)
     result = {}
     result["name"] = source.findAll("a",class_ = "name")[0].text
-    result["followers"] = source.findAll("div",class_ = "meta-block")[0].p.text
-    result["fans"] = source.findAll("div",class_ = "meta-block")[1].p.text
-    result["articles"] = source.findAll("div",class_ = "meta-block")[2].p.text
-    result["words"] = source.findAll("div",class_ = "meta-block")[3].p.text
-    result["likes"] = source.findAll("div",class_ = "meta-block")[4].p.text
+    result["followers"] = int(source.findAll("div",class_ = "meta-block")[0].p.text)
+    result["fans"] = int(source.findAll("div",class_ = "meta-block")[1].p.text)
+    result["articles"] = int(source.findAll("div",class_ = "meta-block")[2].p.text)
+    result["words"] = int(source.findAll("div",class_ = "meta-block")[3].p.text)
+    result["likes"] = int(source.findAll("div",class_ = "meta-block")[4].p.text)
     Assets_temp = source.findAll("div",class_ = "meta-block")[5].p.text
-    result["total_assets"] = Assets_temp.replace(".","").replace("w","000")
+    result["total_assets"] = int(Assets_temp.replace(".","").replace("w","000"))
     return result
 
 def GetUserBadgesList(user_url):
@@ -229,8 +232,8 @@ def GetUserManageableCollectionInfo(user_url):
     source = requests.get(url,headers = request_UA)
     source = json.loads(source.content)
     result_list = []
-    Collcetion_List = source["manageable_collections"]
-    for item in Collcetion_List:
+    Collection_List = source["manageable_collections"]
+    for item in Collection_List:
         info = {}
         info["cid"] = item["id"]
         info["name"] = item["title"]
@@ -252,8 +255,8 @@ def GetUserOwnCollectionInfo(user_url):
     source = requests.get(url,headers = request_UA)
     source = json.loads(source.content)
     result_list = []
-    Collcetion_List = source["own_collections"]
-    for item in Collcetion_List:
+    Collection_List = source["own_collections"]
+    for item in Collection_List:
         info = {}
         info["cid"] = item["id"]
         info["name"] = item["title"]
@@ -301,7 +304,7 @@ def GetBeikeIslandTradeRanking(page = 1):
         info["bkuid"] = user["userid"]
         info["jianshuname"] = user["jianshuname"]
         info["amount"] = user["totalamount"]
-        info["time"] = user["totaltime"]
+        info["times"] = user["totaltime"]
         result_list.append(info)
     return result_list
         
@@ -402,7 +405,7 @@ def GetBeiKeIslandTradePrice(Trade_type):
     First_Dict = Raw_Data[0]
     return First_Dict["Price"]
 
-def GetUserNoteTitleList(user_url,pages = 1):
+def GetUserArticlesTitleList(user_url,pages = 1):
     """该函数用于获取用户的文章标题列表
 
     Args:
@@ -419,10 +422,10 @@ def GetUserNoteTitleList(user_url,pages = 1):
         url = user_url + "?page=" + str(page)
         html = requests.get(url,headers = request_UA)
         source = bs4.BeautifulSoup(html.content,parser)
-        Note_List = source.findAll("li")
-        for note in Note_List:
-            note = note.find("div",class_ = "content")
-            result = note.find("a",class_ = "title").text
+        Article_List = source.findAll("li")
+        for article in Article_List:
+            article = article.find("div",class_ = "content")
+            result = article.find("a",class_ = "title").text
             result_list.append(result)
         if list_len == len(result_list):
             break
@@ -444,7 +447,6 @@ def GetUserFollowersList(user_url,pages = 1):
     for page in range(pages):
         page = page + 1
         url = raw_url + str(page)
-        print(url)
         html = requests.get(url,headers = request_UA)
         source = bs4.BeautifulSoup(html.content,parser)
         data_list = source.findAll("a",class_ = "name")
@@ -468,7 +470,6 @@ def GetUserFansList(user_url,pages = 1):
     for page in range(pages):
         page = page + 1
         url = raw_url + str(page)
-        print(url)
         html = requests.get(url,headers = request_UA)
         source = bs4.BeautifulSoup(html.content,parser)
         data_list = source.findAll("a",class_ = "name")
@@ -540,15 +541,29 @@ def GetArticleText(article_url):
     result = result.replace("\n","")
     return result
 
-def GetUserArticlesList(user_url,page = 1):
-    url = user_url + "?page=" + str(page)
-    html = requests.get(url,headers = request_UA)
-    source  = bs4.BeautifulSoup(html.content,parser)
-    html_list = source.findAll("a",class_ = "title",href = True)
+def GetUserArticlesInfo(user_url,page = 1):
+    url = user_url.replace("https://www.jianshu.com/u/","https://www.jianshu.com/asimov/users/slug/")
+    url = url + "/public_notes?page=" + str(page) + "&count=10&order_by=shared_at"
+    source = requests.get(url,headers = request_UA)
+    source = json.loads(source.content)
     result_list = []
-    for item in html_list:
-        result_list.append("https://www.jianshu.com" + item["href"])
-    return result_list
+    for item in source:
+        info = {}
+        item = item["object"]["data"]
+        info["title"] = item["title"]
+        info["nid"] = item["id"]
+        info["slug"] = item["slug"]
+        info["time"] = item["first_shared_at"]
+        info["views_count"] = item["views_count"]
+        info["topped"] = item["is_top"]
+        info["likes_count"] = item["likes_count"]
+        info["paid"] = item["paid"]
+        info["commentale"] = item["commentable"]
+        info["comments_amount"] = item["public_comments_count"]
+        info["fp_amount"] = item["total_fp_amount"]
+        info["rewards_amount"] = item["total_rewards_count"]
+        result_list.append(info)
+    return result_list    
 
 def GetDailyArticleRankList():
     """该函数返回日更排行榜中用户的基础信息
@@ -569,4 +584,105 @@ def GetDailyArticleRankList():
         result_list.append(info)
     return result_list
 
-print(GetArticleText("https://www.jianshu.com/p/d1bef91888d8"))
\ No newline at end of file
+def GetCollectionArticlesList(collection_url,page = 1):
+    url = collection_url.replace("https://www.jianshu.com/c","https://www.jianshu.com/asimov/collections/slug")
+    url = url + "/public_notes?page=" + str(page) + "&count=20&order_by=added_at"
+    source = requests.get(url,headers = request_UA)
+    source = json.loads(source.content)
+    result_list = []
+    for item in source:
+        item_info = {}
+        item = item["object"]["data"]
+        item_info["title"] = item["title"]
+        item_info["nid"] = item["id"]
+        item_info["likes_count"] = item["likes_count"]
+        item_info["time"] = item["first_shared_at"]
+        item_info["commentable"] = item["commentable"]
+        item_info["paid"] = item["paid"]
+        item_info["topped"] = item["is_top"]
+        item_info["comments_count"] = item["public_comments_count"]
+        item_info["fp_amount"] = item["total_fp_amount"]
+        item_info["rewards_count"] = item["total_rewards_count"]
+        result_list.append(item_info)
+    return result_list
+
+def GetArticleFPList(date = "latest"):
+    if date == "latest":
+        date = time.strftime("%Y%m%d", time.localtime())
+    url = "https://www.jianshu.com/asimov/fp_rankings/voter_notes?date=" + str(date)
+    source = requests.get(url,headers = request_UA)
+    source = json.loads(source.content)
+    result = {}
+    result["total_fp"] = source["fp"]
+    result["total_fp_to_authors"] = source["author_fp"]
+    result["total_fp_to_voters"] = source["fp"] - source["author_fp"]
+    data = []
+    for ranking,item in enumerate(source["notes"]):
+        info = {}
+        ranking = ranking + 1
+        info["ranking"] = ranking
+        info["article_title"] = item["title"] 
+        info["author_name"] = item["author_nickname"]
+        info["author_slug"] = item["slug"]
+        info["total_fp"] = item["fp"]
+        info["fp_to_author"] = item["author_fp"]
+        info["fp_to_voters"] = item["voter_fp"]
+        data.append(info)
+    result["data"] = data
+    return data
+
+def GetArticleTitle(article_url):
+    url = article_url.replace("https://www.jianshu.com/p/","")
+    url = "https://www.jianshu.com/asimov/p/" + url
+    source = requests.get(url,headers = request_UA)
+    source = json.loads(source.content)
+    return source["public_title"]
+
+def GetArticleID(article_url):
+    url = article_url.replace("https://www.jianshu.com/p/","")
+    url = "https://www.jianshu.com/asimov/p/" + url
+    source = requests.get(url,headers = request_UA)
+    source = json.loads(source.content)
+    return source["id"]
+
+def GetArticleLikeCount(article_url):
+    url = article_url.replace("https://www.jianshu.com/p/","")
+    url = "https://www.jianshu.com/asimov/p/" + url
+    source = requests.get(url,headers = request_UA)
+    source = json.loads(source.content)
+    return source["likes_count"]
+
+def GetArticleCommentCount(article_url):
+    url = article_url.replace("https://www.jianshu.com/p/","")
+    url = "https://www.jianshu.com/asimov/p/" + url
+    source = requests.get(url,headers = request_UA)
+    source = json.loads(source.content)
+    return source["public_comment_count"]
+
+def GetArticleFPCount(article_url):
+    url = article_url.replace("https://www.jianshu.com/p/","")
+    url = "https://www.jianshu.com/asimov/p/" + url
+    source = requests.get(url,headers = request_UA)
+    source = json.loads(source.content)
+    result = source["total_fp_amount"]
+    result = list(str(result))
+    result.insert(-3,".")
+    result = "".join(result)
+    result = float(result)
+    return result
+
+def GetArticlePublishTime(article_url):
+    url = article_url.replace("https://www.jianshu.com/p/","")
+    url = "https://www.jianshu.com/asimov/p/" + url
+    source = requests.get(url,headers = request_UA)
+    source = json.loads(source.content)
+    raw_text = source["first_shared_at"]
+    result = StrToDatetime(raw_text)
+    return result
+
+def GetCollectionArticlesCount(collection_url):
+    html = requests.get(collection_url,headers = UA)
+    source = bs4.BeautifulSoup(html.content,parser)
+    result = source.findAll("div",class_ ="info")[0].text
+    result = re.search("\d+",result).group(0)
+    return result
\ No newline at end of file
